#include <stdio.h>
#include <stdarg.h>
#include <time.h>

#include "gg_utils.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#ifdef HAVE_LIBGLIB
#include <glib.h>
#endif

#ifdef HAVE_SYS_TIME_H
#include <sys/time.h>
#endif

/*
 * A wrapper around vsnprintf.
 */

void
gg_snprintf(char *dest, unsigned long len, const char *fmt, ...)
{
  va_list args;
  va_start(args,fmt);
    
#ifdef HAVE_VSNPRINTF
  vsnprintf(dest,len,fmt,args);
#elif defined HAVE_LIBGLIB
  g_vsnprintf(dest,len,fmt,args);
#else
  UNUSED(len);
  vsprintf(dest,fmt,args);
#endif
  va_end(args);
}

/* Get the time of day, calling gettimeofday from sys/time.h
 * if available, otherwise substituting a workaround for portability.
 */

double
gg_gettimeofday(void)
{
#ifdef HAVE_GETTIMEOFDAY
  struct timeval tv;
  gettimeofday(&tv, NULL);
  return tv.tv_sec + 1.e-6*tv.tv_usec;
#else
  return time(NULL);
#endif
}

const char *
gg_version(void) {
  return VERSION;
}



/*
 * Local Variables:
 * tab-width: 8
 * c-basic-offset: 2
 * End:
 */
